@@ -335,6 +335,8 @@ void JSFXCodeContainer::produceClass()
     // host (Reaper)
     *fOut << "function init_instances() (";
     tab(n + 1, *fOut);
+    gGlobal->gJSFXVisitor->generatePolyInit();
+    tab(n + 1, *fOut);
     *fOut << "voice_idx = 0; ";
     tab(n + 1, *fOut);
     *fOut << "while(voice_idx < nvoices) ( ";
@@ -473,8 +475,8 @@ void JSFXScalarCodeContainer::generateCompute(int n)
     *fOut << "control();";
     tab(n, *fOut);
 
-    // @serialize section is used to prevent init values (in @init section) to override the serialized value 
-    // It is here just to be non-empty, as described in JSFX documentation
+    // @serialize section is used to prevent init values (in @init section) to override the
+    // serialized value It is here just to be non-empty, as described in JSFX documentation
     tab(n, *fOut);
     *fOut << "@serialize";
     tab(n, *fOut);
